## AppOpener 👏

The AppOpener package is the PYPI module which helps in opening any application **without knowing it's absoulute path**. The module works by making use of <b> App name </b> and <b> App Id </b>

AppOpener works on python version 3.5 or above 3.5+

> **Note**
> This is version of [AppOpener](https://pypi.org/project/AppOpener), is only functional on windows.

Visit official documentation of AppOpener [here](https://AppOpener.readthedocs.io/en/latest/)

The latest development version is always available at the [Github](https://github.com/athrvvvv/AppOpener) repository.

---

> ### Features:

1. Open applications
2. Create list of Apps & Ids

---

> ### Install Package 📦

<b>1. Install from PyPi</b>

```
pip install AppOpener
```

<b>2. Install from git repository</b>

```
python -m pip install https://codeload.github.com/athrvvvv/AppOpener/tar.gz/refs/tags/v1.0
```

---

> ### Quick start ⚡

```
from AppOpener import run, mklist
run("telegram, whatsapp")
mklist(name="app_data.json")
```

---
> ### Building package 🔨

```
git clone https://github.com/athrvvvv/AppOpener.git
cd AppOpener
python setup.py sdist bdist_wheel
```
The latest release is always available at the Github [releases](https://github.com/athrvvvv/AppOpener/releases).

> ### CHANGELOG 🤓

All notable changes to this project will be documented in this [file](./CHANGELOG.md).

[Telegram](https://telegram.me/buddy_join)&nbsp; [Twitter](https://twitter.com/athrvvvvv)&nbsp;  [YouTube](https://www.youtube.com/channel/UC-8KiGHbuUD2HiJtaYAKSIQ)&nbsp; [Mail](mailto:athrvchaulkar@gmail.com)
